@@ -170,8 +170,21 @@ void MainWindow::screenSlot(bool b)
         QTimer::singleShot(hideTbTimeout, this, SLOT(hideToolBar()));
     }
 }
+/*
+void MainWindow::InitLOG()
+{
+    logfile.setFileName("spotme.txt");
+    //out.setString(&logfile);
+}
 
-
+void MainWindow::LOG(QString txt)
+{
+    if(dir.exists("/media/mmc1/"))
+        dir.setCurrent("/media/mmc1/");
+    else
+        dir.setCurrent("/home/user/");
+}
+*/
 void MainWindow::positionUpdated(const QGeoPositionInfo &info)
 {
     if (info.isValid())
@@ -188,13 +201,14 @@ void MainWindow::positionUpdated(const QGeoPositionInfo &info)
             sLastLat = QString::number(dLastLat);
             sLastLng = QString::number(dLastLng);
 
-            source->stopUpdates();
+            //source->stopUpdates();
             updateGoogleMap();
-            source->startUpdates();
+            //source->startUpdates();
         }
-        /*
         else
         {
+            qDebug() << "isNewPositionOK" << false;
+            /*
             if(++consecutiveNonOK > 10)
             {
                 qDebug() << "consecutiveNonOK" << consecutiveNonOK;
@@ -203,8 +217,8 @@ void MainWindow::positionUpdated(const QGeoPositionInfo &info)
                     QMessageBox::Ok);
                 on_m_spotme_toggled(false);
             }
+            */
         }
-        */
     }
     else {
 //        QMessageBox::information(this, tr("GPS Error"),
@@ -248,7 +262,7 @@ bool MainWindow::isNewPositionOK(QGeoCoordinate newCoord)
      -------------------------------------*/
     if( (distance > 27) and (newCooordinateCount > 0) )
     {
-        if(updateCount > 5)
+        if(updateCount > 10)
             return false;
     }
     else
